@@ -308,6 +308,7 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	pinger->output = glade_xml_get_widget (xml, "ping_output");
 	pinger->limited = glade_xml_get_widget (xml, "ping_limited");
 	pinger->button = glade_xml_get_widget (xml, "ping_button");
+	pinger->graph = glade_xml_get_widget (xml, "ping_graph");
 	pinger->sensitive = pinger->host;
 	pinger->label_run = _("Ping");
 	pinger->label_stop = NULL;
@@ -319,7 +320,7 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	pinger->max = glade_xml_get_widget (xml, "ping_maximum");
 	pinger->packets_transmitted = glade_xml_get_widget (xml, "ping_packets_transmitted");
 	pinger->packets_received = glade_xml_get_widget (xml, "ping_packets_received");
-	pinger->packets_loss = glade_xml_get_widget (xml, "ping_packets_loss");
+	pinger->packets_success = glade_xml_get_widget (xml, "ping_packets_success");
 
 	pinger->status_bar = glade_xml_get_widget (xml, "statusbar");
 	pinger->stbar_text = NULL;
@@ -366,6 +367,9 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	g_signal_connect (G_OBJECT (pinger->button), "clicked",
 			  pinger->button_callback,
 			  pinger);
+	g_signal_connect (G_OBJECT (pinger->graph), "expose-event",
+			  G_CALLBACK (on_ping_graph_expose),
+			  pinger);
 
 	return pinger;
 }
@@ -711,18 +715,18 @@ nettool_lookup_setup_combo_type (Netinfo *lookup)
 	GtkTreeIter   iter;
 	GtkCellRenderer *renderer;
 	gchar *types[] = {
-		"Default Information",
-		"Internet Address",
-		"Canonical Name",
-		"CPU / OS Type",
-		"Mailbox Exchange",
-		"Mailbox Information",
-		"Name Server",
-		"Host name for Address",
-		"Start-of-authority",
-		"Text Information",
-		"Well Known Services",
-		"Any / All Information",
+		N_("Default Information"),
+		N_("Internet Address"),
+		N_("Canonical Name"),
+		N_("CPU / OS Type"),
+		N_("Mailbox Exchange"),
+		N_("Mailbox Information"),
+		N_("Name Server"),
+		N_("Host name for Address"),
+		N_("Start-of-authority"),
+		N_("Text Information"),
+		N_("Well Known Services"),
+		N_("Any / All Information"),
 		NULL
 	};
 
@@ -731,7 +735,7 @@ nettool_lookup_setup_combo_type (Netinfo *lookup)
 	for (i=0; types[i]; i++) {
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    0, types[i], -1);
+				    0, _(types[i]), -1);
 	}
 	
 	gtk_combo_box_set_model (GTK_COMBO_BOX (lookup->type), model);
